@@ -91,6 +91,16 @@ def get_application_data(
     }
 
 
+def get_application_minimal_applicant_data(**kwargs):
+    return {
+        'applicant.data.completename.data.name': 'Vittorino',
+        'applicant.data.completename.data.surname': 'Coliandro',
+        'applicant.data.fiscal_code.data.fiscal_code': 'CLNVTR76P01G822Q',
+        'payment_amount': '3',
+        **kwargs,
+    }
+
+
 def get_application_payment_data(**kwargs):
     return {
         'reason': 'PagamentoTari-3c819c1d-6587-448d-8ba4-3b6f23e87ed4',
